Feature toggles generated by gradle plugin
------------------------------------------------------------
[![CircleCI](https://circleci.com/gh/dvpermyakov/rx-kotlin/tree/master.svg?style=shield)](https://circleci.com/gh/dvpermyakov/feature-toggles-gradle/tree/master)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

This gradle plugin allows you to generate Kotlin classes (.kt) using the interfaces:
```Kotlin
interface FeatureToggle {
    val id: FeatureToggleId
    val enabled: Boolean
    val name: String
}
```
```Kotlin
interface FeatureToggleConfig {
    val featureToggles: List<FeatureToggle>
}
```


For example, you set `FeatureToggleId`:
```Kotlin
enum class FeatureToggleId {
    FEATURE;
}
```

And you apply and configure plugin in `build.gradle.kts`:
```Kotlin
apply<FeatureTogglePlugin>()
configure<FeatureTogglePluginExtension> {
    configName = "default"
    toggles = listOf(
        FeatureToggle(
            id = "FEATURE",
            enabled = true,
            name = "Default feature"
        )
    )
}
```

Plugin generates these classes:
```Kotlin
@Generated
object FeatureToggle_FEATURE : FeatureToggle {
  override val id: FeatureToggleId = FeatureToggleId.FEATURE
  override val enabled: Boolean = true
  override val name: String = "Default feature"
}
```
```Kotlin
@Generated
object FeatureToggleConfig_default : FeatureToggleConfig {
  override val featureToggles: List<FeatureToggle> = listOf(FeatureToggle_FEATURE)
}
```